@@ -14,6 +14,14 @@ import threading
 from django.conf import settings
 from django.core.signals import request_finished
 
+try:
+    # Django >= 1.10
+    from django.utils.deprecation import MiddlewareMixin
+except ImportError:
+    # Not required for Django <= 1.9, see:
+    # https://docs.djangoproject.com/en/1.10/topics/http/middleware/#upgrading-pre-django-1-10-style-middleware
+    MiddlewareMixin = object
+
 from raven.contrib.django.resolver import RouteResolver
 
 
@@ -27,11 +35,17 @@ def is_ignorable_404(uri):
     )
 
 
-class Sentry404CatchMiddleware(object):
+class Sentry404CatchMiddleware(MiddlewareMixin):
     def process_response(self, request, response):
+        if response.status_code != 404:
+            return response
+
+        if is_ignorable_404(request.get_full_path()):
+            return response
+
         from raven.contrib.django.models import client
 
-        if response.status_code != 404 or is_ignorable_404(request.get_full_path()) or not client.is_enabled():
+        if not client.is_enabled():
             return response
 
         data = client.get_data_from_request(request)
@@ -52,7 +66,7 @@ class Sentry404CatchMiddleware(object):
     # sentry_exception_handler(sender=Sentry404CatchMiddleware, request=request)
 
 
-class SentryResponseErrorIdMiddleware(object):
+class SentryResponseErrorIdMiddleware(MiddlewareMixin):
     """
     Appends the X-Sentry-ID response header for referencing a message within
     the Sentry datastore.
@@ -105,7 +119,7 @@ class SentryMiddleware(threading.local):
     def request_finished(self, **kwargs):
         from raven.contrib.django.models import client
 
-        if self._txid:
+        if getattr(self, '_txid', None):
             client.transaction.pop(self._txid)
             self._txid = None
 
